DROP TABLE Kursbesuche
DROP TABLE Kurskontrolle
DROP TABLE Personen
DROP TABLE Kurse
DROP TABLE Kursthemen
DROP TABLE Kursleiter
DROP TABLE Funktionen
GO

CREATE TABLE KURSLEITER (KLNR NUMERIC(3) NOT NULL,
 STATUS VARCHAR(1) NOT NULL,
 PNR NUMERIC(6) NULL,
 NAME VARCHAR(20) NOT NULL,
 VORNAME VARCHAR(15) NOT NULL,
 FIRMA VARCHAR(20) NULL,
 KURSERFAHRUNG NUMERIC(2) NULL)

CREATE TABLE KURSTHEMEN (TNR NUMERIC(2) NOT NULL,
 THEMENGEBIET VARCHAR(40) NOT NULL)

CREATE TABLE PERSONEN (PNR NUMERIC(6) NOT NULL,
 NAME VARCHAR(20) NOT NULL,
 VORNAME VARCHAR(15) NOT NULL,
 FNR NUMERIC(2) NOT NULL,
 LOHNSTUFE NUMERIC(1) NOT NULL)

CREATE TABLE FUNKTIONEN (FNR NUMERIC(2) NOT NULL,
 FUNKTION VARCHAR(25) NOT NULL)

CREATE TABLE KURSBESUCHE (PNR NUMERIC(6) NOT NULL,
 KNR NUMERIC(3) NOT NULL,
 KLNR NUMERIC(3) NOT NULL,
 DATUM DATETIME NOT NULL)

CREATE TABLE KURSKONTROLLE (KNR NUMERIC(3) NOT NULL,
 FNR NUMERIC(2) NOT NULL)

CREATE TABLE KURSE (KNR NUMERIC(3) NOT NULL,
 KURSBEZEICHNUNG VARCHAR(40) NOT NULL,
 KURSORT VARCHAR(10) NOT NULL,
 TNR NUMERIC(2) NOT NULL)

ALTER TABLE KURSLEITER ADD CONSTRAINT ID_KURSLEITER PRIMARY KEY (KLNR) 
ALTER TABLE KURSTHEMEN ADD CONSTRAINT ID_KURSTHEMEN PRIMARY KEY (TNR) 
ALTER TABLE PERSONEN ADD CONSTRAINT ID_PERSONEN PRIMARY KEY (PNR) 
ALTER TABLE FUNKTIONEN ADD CONSTRAINT ID_FUNKTIONEN PRIMARY KEY (FNR) 
ALTER TABLE KURSBESUCHE ADD CONSTRAINT ID_KURSBESUCHE PRIMARY KEY (PNR,KNR,KLNR) 
ALTER TABLE KURSKONTROLLE ADD CONSTRAINT ID_KURSKONTROLLE PRIMARY KEY (KNR,FNR) 
ALTER TABLE KURSE ADD CONSTRAINT ID_KURSE PRIMARY KEY (KNR) 

ALTER TABLE KURSE ADD CONSTRAINT BEZ_03 FOREIGN KEY(TNR) REFERENCES KURSTHEMEN(TNR)
ALTER TABLE PERSONEN ADD CONSTRAINT BEZ_01 FOREIGN KEY(FNR) REFERENCES FUNKTIONEN(FNR)
ALTER TABLE KURSBESUCHE ADD CONSTRAINT BEZ_06 FOREIGN KEY(KLNR) REFERENCES KURSLEITER(KLNR)
ALTER TABLE KURSBESUCHE ADD CONSTRAINT BEZ_05 FOREIGN KEY(PNR) REFERENCES PERSONEN(PNR)
ALTER TABLE KURSBESUCHE ADD CONSTRAINT BEZ_04 FOREIGN KEY(KNR) REFERENCES KURSE(KNR)
ALTER TABLE KURSKONTROLLE ADD CONSTRAINT BEZ_02 FOREIGN KEY(FNR) REFERENCES FUNKTIONEN(FNR)
ALTER TABLE KURSKONTROLLE ADD CONSTRAINT BEZ_07 FOREIGN KEY(KNR) REFERENCES KURSE(KNR)

CREATE UNIQUE INDEX IX_KURSTHEMEN_THEMENGEBIET ON KURSTHEMEN(THEMENGEBIET)
CREATE INDEX IX_BEZ_03 ON KURSE(TNR)
CREATE INDEX IX_BEZ_01 ON PERSONEN(FNR)
CREATE UNIQUE INDEX IX_FUNKTIONEN_FUNKTION ON FUNKTIONEN(FUNKTION)
CREATE INDEX IX_BEZ_04 ON KURSBESUCHE(KNR)
CREATE INDEX IX_BEZ_05 ON KURSBESUCHE(PNR)
CREATE INDEX IX_BEZ_06 ON KURSBESUCHE(KLNR)
CREATE INDEX IX_BEZ_02 ON KURSKONTROLLE(FNR)
CREATE INDEX IX_BEZ_07 ON KURSKONTROLLE(KNR)
GO

INSERT INTO Funktionen (FNr,Funktion)
VALUES (1,'Vorarbeiter')
INSERT INTO Funktionen (FNr,Funktion)
VALUES (2,'Meister')
INSERT INTO Funktionen (FNr,Funktion)
VALUES (3,'Chemiker')
INSERT INTO Funktionen (FNr,Funktion)
VALUES (4,'Bereichsleiter')
INSERT INTO Funktionen (FNr,Funktion)
VALUES (5,'Informatiker')

INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (1,'I',345727,'Steiner','Ren',NULL,3)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (3,'I',232452,'Mller','Hugo',NULL,1)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (4,'I',233456,'Mller','Franz',NULL,4)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (2,'E',NULL,'Suter','Rolf','GigaSoft',NULL)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (5,'E',NULL,'Vogt','Peter','Quasar',NULL)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (6,'I',845622,'Huber','Walter',NULL,3)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (7,'E',NULL,'Krieg','Stefan','Funkenflug',NULL)
INSERT INTO Kursleiter (KlNr,Status,PNr,Name,Vorname,Firma,Kurserfahrung)
VALUES (8,'E',NULL,'Freundlich','Andreas','Harmonie',NULL)

INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (1,'Sicherheit und Umweltschutz')
INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (2,'Fhrung und Zusammenarbeit')
INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (3,'PC-Kurse')
INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (4,'Arbeitstechnik')
INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (5,'Projekte')
INSERT INTO Kursthemen (TNr,Themengebiet)
VALUES (6,'Schulung')

INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (123,'Arbeitshygiene','2510.EG.25',1)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (562,'Fhren einer Gruppe','1010.4.08',2)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (234,'Prsentationstechnik','1010.4.08',4)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (341,'Textverarbeitung','2015.1.10',3)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (245,'Kostenschtzung','1010.2.05',5)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (412,'Tabellenkalkulation','2015.1.10',3)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (454,'Elektrostatische Aufladung','4001.EG.20',1)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (255,'Datenbanken','2015.2.05',3)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (455,'Terminplanung','1010.4.08',5)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (345,'Schwierige Gesprche fhren','1010.2.05',2)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (283,'Abfallentsorgung','4001.EG.20',1)
INSERT INTO Kurse (KNr,Kursbezeichnung,Kursort,TNr)
VALUES (776,'Wartung von Anlagen','1010.2.05',4)

INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(100001,'Steffen','Felix',3,5)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(232452,'Mller','Hugo',1,1)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(334643,'Meier','Hans',2,5)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(567231,'Schmid','Beat',3,4)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(345727,'Steiner','Ren',5,5)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(233456,'Mller','Franz',4,7)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(132442,'Osswald','Kurt',1,2)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(345678,'Metzger','Paul',1,1)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(344556,'Scherrer','Daniel',2,4)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(845622,'Huber','Walter',4,8)
INSERT INTO Personen (PNr,Name,Vorname,FNr,Lohnstufe)
VALUES(625342,'Gerber','Roland',3,4)

INSERT INTO Kurskontrolle (FNr,KNr) VALUES (1,123)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,123)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,123)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,123)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,562)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,562)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,562)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,234)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (5,234)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,341)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,245)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,245)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,412)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,412)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (1,454)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,454)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,454)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,454)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,255)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,455)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,455)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (4,345)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (1,283)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,283)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (3,283)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (1,776)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (2,776)
INSERT INTO Kurskontrolle (FNr,KNr) VALUES (5,245)

INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (100001,245,4,'23-Jun-92')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (100001,412,2,'7-Aug-90')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (100001,454,7,'12-Jan-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (345678,123,6,'3-Feb-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (345678,776,3,'15-Apr-92')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (344556,412,2,'10-Jun-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (334643,412,2,'7-Aug-90')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (625342,255,1,'21-Jul-92')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (845622,345,8,'11-Nov-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (100001,255,1,'21-Jul-92')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (232452,454,7,'17-Sep-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (132442,454,7,'17-Sep-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (345678,454,7,'17-Sep-91')
INSERT INTO Kursbesuche (PNr,KNr,KlNr,Datum)
VALUES (345678,123,4,'25-Aug-92')


